function varargout = getprefs(varargin)
% GETPREFS(PREF1NAME, PREF1DEFAULT, ...)
% 	Gets global preferences for the current m-file, using the specified
% 	default value if the desired preference is found to be absent.
% 
% E.g:
% 	[A B] = GETPREFS('a', 0, 'b', 1);
% 		Get prefs 'a' (defaults to 0) and 'b' (defaults to 1).
% 		Store the results as A and B.
% 	GETPREFS('a', 0, 'b', 1)
% 		No output arguments: variables called 'a' and 'b' are
% 		automatically assigned in the caller.
% 
% 	GETPREFS
% 		returns all the prefs for the current m-file as a struct		
% 	GETPREFS(FUNCNAME)
% 		returns all the prefs for function FUNCNAME as a struct		
% 
% See also SETPREFS, CLEARPREFS.

% Part of PFCMP version 2.5.41, an extension to the PSIGNIFIT toolbox for MATLAB versions 5 and up.
% The license and NO WARRANTY statement for PSIGNIFIT also applies to this release - see psych_legal.m
% Copyright (c) J.Hill 2002.
% mailto:psignifit@bootstrap-software.org
% http://www.bootstrap-software.org/psignifit/

if rem(length(varargin), 2)
	prefvarname = varargin{1};
	varargin(1) = [];
else
	dbs = dbstack;
	if length(dbs) == 1, error('cannot be called from the base workspace'), end
	dbs(1) = [];
	[ans prefvarname ans] = fileparts(dbs(1).name);
end


estr = ['PREFS_' upper(prefvarname)];
eval(['global ' estr])
s = eval(estr);
if ~isstruct(s) | prod(size(s)) ~= 1, s = []; end
[fields vals] = flattenstruct(s);

if isempty(varargin)
	varargout = {s};
else
	[keys defaults err] = keysvals(varargin); error(err)
	assignNames = keys; keys = lower(keys);
	for i = 1:length(keys)
		ind = min(find(strcmp(keys{i}, fields)));
		if isempty(ind), val = []; else val = vals{ind}; end
		if isequal(val, [])
			val = defaults{i};
			s = setfield(s, keys{i}, val);
% 			comment out the line above to prevent defaults from being stored globally
		end
		if nargout
			varargout{i} = val;
		else
			assignin('caller', assignNames{i}, val)
		end
	end
end


if isempty(s)
	clear('global', estr);
else
	eval([estr ' = s;'])
end
