function p = gettrueaxesposition(ax, units)
% P = GETTRUEAXESPOSITION(AX, [UNITS])
% 
% Sure, the 'Position' property gives you /a/ bounding box for an AXES
% object, but if it has a constrained aspect ratio to fit within that
% box, what are its actual coordinates?
% 
% Returns multiple rows for non-scalar handle input.
% 
% See also TRANSLATEAXESCOORDS

% Part of PFCMP version 2.5.41, an extension to the PSIGNIFIT toolbox for MATLAB versions 5 and up.
% The license and NO WARRANTY statement for PSIGNIFIT also applies to this release - see psych_legal.m
% Copyright (c) J.Hill 2002.
% mailto:psignifit@bootstrap-software.org
% http://www.bootstrap-software.org/psignifit/

if nargin < 2, units = 'pixels'; end
if nargin < 1, ax = gca; end

if prod(size(ax)) ~= 1
	p = [];
	for i = 1:prod(size(ax))
		p(i, :) = gettrueaxesposition(ax(i), units);
	end
	return
end

normalized = strcmp(lower(units), 'normalized');
if normalized, units = 'pixels'; end

oldu = get(ax, 'units');
set(ax, 'units', units)
p = get(ax, 'position');
set(ax, 'units', oldu)

if any(strcmp(get(ax, {'plotboxaspectratiomode', 'dataaspectratiomode'}), 'manual'))
	pbar = get(ax, 'plotboxaspectratio');
	pbar = pbar([1 2]) ./ pbar([2 1]);
	axsiz = min(p([3 4]), p([4 3]) .* pbar);
	p(1:2) = p(1:2) + 0.5 * (p(3:4) - axsiz); p(3:4) = axsiz;
	if normalized
		fig = get(ax, 'parent');
		oldu = get(fig, 'units');
		set(fig, 'units', units);
		fp = get(fig, 'position');
		set(fig, 'units', oldu);
		p([1 3]) = p([1 3]) / fp(3);
		p([2 4]) = p([2 4]) / fp(4);
	end
end

