function v = measure(h, unitPropName, units, propName)
% MEASURE(H, UNITS, PROPERTY_NAME)
% 
% 	Set the 'Units' property of handle object H to UNITS.
% 	Get the property PROPERTY_NAME.
% 	Set the 'Units' property of H back the way it was.
% 
% 	e.g:
% 		MEASURE(GCF, 'centimeters', 'position')	
% 	
% MEASURE(H, UNIT_PROP_NAME, UNITS, PROPERTY_NAME)
% 	The same, except UNIT_PROP_NAME is used instead of 'Units'.
% 
% 	e.g:
% 		H = TEXT(0.5, 0.5, 'Hello world');
% 		MEASURE(H, 'fontunits', 'centimeters', 'fontsize')
% 
% See also POSITIONBOX, RESIZEBOX

% Part of PFCMP version 2.5.41, an extension to the PSIGNIFIT toolbox for MATLAB versions 5 and up.
% The license and NO WARRANTY statement for PSIGNIFIT also applies to this release - see psych_legal.m
% Copyright (c) J.Hill 2002.
% mailto:psignifit@bootstrap-software.org
% http://www.bootstrap-software.org/psignifit/

if nargin < 4
	propName = units;
	units = unitPropName;
	unitPropName = 'units';
end
h = h(:); savetextpos = strcmp(lower(unitPropName), 'units') & strcmp(get(h, 'type'), 'text'); % **
try
	oldUnits = get(h, {unitPropName});

	for i = 1:length(h), if savetextpos(i), pos{i} = get(h(i), 'position'); end, end % **
	set(h, unitPropName, units)
	v = get(h, propName);
	set(h, {unitPropName}, oldUnits)
	
	for i = 1:length(h), if savetextpos(i),  set(h(i), 'position', pos{i}); end, end % **
catch
	error(lasterr)
end

% The three lines marked ** are added as a workaround to a bug in MATLAB for Mac
% (quelle surprise): when the units of a TEXT object are changed and changed back,
% it mysteriously moves one pixel across and down
